==> nextcloud-app-spreed-4.0.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/sq.js <==
OC.L10N.register(
    "spreed",
    {
    "Saved" : "U ruajt",
    "TURN server shared secret" : "Serveri TURN ndan sekret",
    "TURN server protocols" : "Protokollet e serverit TURN",
    "UDP and TCP" : "UDP dhe TCP",
    "UDP only" : "Vetëm UDP",
    "TCP only" : "Vetëm TCP",
    "Screensharing is not supported by your browser." : "Ndarja e erkaneve nuk është e mbështetur nga shfletuesi juaj ",
    "Screensharing requires the page to be loaded through HTTPS." : "Ndarja e ekranit kërkon faqen të ngarkohet përmes HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Ndarja e ekranit punon vetëm me Firefox, versionin 52 ose më të ri.",
    "Screensharing extension is required to share your screen." : "Zgjerim i ndarja së Ekranit është i nevojshëm për të ndarë ekranin tuaj.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Ju lutem përdorni një browser tjetër si Firefox ose Chrome për të ndarë ekranin tuaj.",
    "An error occurred while starting screensharing." : "Ndodhi një gabim gjatë fillimit të ndarjes së ekranit.",
    "Waiting for {participantName} to join the call …" : "Duke pritur për {participantName} që ti bashkohet telefonatës ...",
    "Waiting for others to join the call …" : "Duke pritur që të tjerët t'i bashkohen thirrjes ...",
    "Copy" : "Kopjo",
    "Copied!" : "U kopjua!",
    "Not supported!" : "Nuk mbështetet!",
    "Press ⌘-C to copy." : "Shtyni ⌘-C që të kopjoni.",
    "Press Ctrl-C to copy." : "Shtyp Ctrl-C për të kopjuar",
    "Share screen" : "Ndaje ekranin",
    "Show your screen" : "Shfaq ekranin tënd",
    "Stop screensharing" : "Ndalo ndarjen e ekranit",
    "Password" : "Fjalëkalim",
    "Cancel" : "Anulo",
    "Leave call" : "Lini një thirrje",
    "Share link" : "Shpërndaj ndërlidhjen",
    "Rename" : "Riemëroj",
    "You" : "Ju",
    "Guest" : "I ftuar",
    "No other people in this call" : "Jo njerëz të tjerë në këtë thirrje",
    "Waiting for camera and microphone permissions" : "Duke pritur për autorizimin e kameras dhe mikrofonit ",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Ju lutemi, ti jepni akses browser-it tuaj për të përdorur kameran dhe mikrofonin në mënyrë që të përdorni këtë app.",
    "Disable video" : "Çaktivizo video",
    "Access to microphone & camera is only possible with HTTPS" : "Aksesi në mikrofon & kamera është i mundur vetëm me HTTPS",
    "Access to microphone & camera was denied" : "Aksesi tek mikrofoni & kamera u mohua",
    "WebRTC is not supported in your browser" : "WebRTC nuk mbështetet nga shfletuesi juaj.",
    "Please use a different browser like Firefox or Chrome" : "Ju lutem zgjidhni një shfletues tjetër si Firefox apo Chrome",
    "Error while accessing microphone & camera" : "gabim ",
    "WebRTC is not supported in your browser :-/" : "WebRTC nuk suportohet nga shfletuesi juaj :-/",
    "{participantName}'s screen" : "Ekrani i {participantName}",
    "Guest's screen" : "Ekrani i të ftuarit",
    "Your screen" : "Ekrani juaj",
    "_%n guest_::_%n guests_" : ["%n të ftuar","%n të ftuar"],
    "_%n other guest_::_%n other guests_" : ["%n përdorues të tjerë","%n të tjerë"],
    ", " : ",",
    "%s mentioned you in a group conversation: %s" : "%s ju përmendi në një bisedë grupi: %s",
    "A guest mentioned you in a group conversation: %s" : "Një i ftuar ju përmendi në një bisedë grupi: %s",
    "%s invited you to a private conversation" : "%s ju ftoi në një bisedë private",
    "%s invited you to a group conversation: %s" : "%s ju ftoi në një bisedë grupi: %s",
    "TURN server" : "Serveri TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "Serveri TURN përdoret për të përcjellë trafikun nga pjesëmarrësit pas një firewalli.",
    "Video calls" : "Telefonata video",
    "(group)" : "(grup)",
    "New public call" : "Thirrje e re publike",
    "Looking great today! :)" : "Ju dukeni perfekt sot! :)",
    "Time to call your friends" : "Koha për të thirrur shokët tuaj",
    "You can set your name on the top right of this page so other participants can identify you better." : "Ju mund të vendosni emrin tuaj në të djathtën e sipërme të kësaj faqeje që pjesëmarrësit e tjerë tju indentifikojnë më mirë ",
    "This call has ended" : "Kjo thirrje ka përfunduar",
    "Saving failed" : "Ruajtja dështoi",
    "Add person" : "Shto person",
    "and you" : "dhe ju",
    "Please adjust your configuration" : "Ju lutem rregulloni konfigurimin tuaj",
    "{actor} invited you to a private call" : "{actor} ju ftoi në një telefonatë private",
    "{actor} invited you to a group call" : "{actor} ju ftoi për një telefonatë grupi",
    "{actor} invited you to the call {call}" : "{actor} ju ftoi në thirrjen {call}",
    "You were invited to a <strong>video call</strong>" : "Ju jeni ftuar në një <strong> thirrje videoje</strong>",
    "Video call" : "Thirrje me Video",
    "Invalid format, must be stunserver:port." : "Format i pavlefshëm, duhet të jetë stunserver:port.",
    "Invalid port specified." : "Port i specfikuar në mënyrë të gabuar.",
    "Invalid protocols specified." : "Protokolle të pavlefshme të specifikuara",
    "%s invited you to a private call" : "%s ju ftoi në një thirrje private",
    "{user} invited you to a private call" : "{user} ju ftoi në një thirrje private",
    "%s invited you to a group call: %s" : "%s ju ka ftuar në një thirrje grupi: %s",
    "{user} invited you to a group call: {call}" : "{user} ju ftoi në një thirrje grupi: {call}",
    "%s invited you to a group call" : "%s ju ftoi t'i bashkoheni një thirrje në grup",
    "{user} invited you to a group call" : "{user} ju ftoi në një thirrje në grup",
    "Fullscreen" : "Ekran i plotë",
    "Mute audio" : "Mute audio",
    "Smile in 3… 2… 1!" : "Buzëqesh në 3...2...1!",
    "Choose person …" : "Zgjidhni personin ...",
    "The STUN server is necessary so participants can connect to calls. The TURN server makes sure connection works even through firewalls." : "Serveri STUN është i nevojshëm që pjesëmarrësit të mund të lidhen me thirrjet. Serveri TURN siguron që lidhja të funksionojë edhe përmes firewalls.",
    "STUN server" : "Server STUN",
    "The STUN server is used to determine the public IP address of participants behind a router." : "Serveri STUN përdoret për të përcaktuar adresë IP publike të pjesëmarrësve prapa një routeri."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-4.0.1-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/sq.js <==
OC.L10N.register(
    "spreed",
    {
    "Saved" : "U ruajt",
    "TURN server shared secret" : "Serveri TURN ndan sekret",
    "UDP and TCP" : "UDP dhe TCP",
    "UDP only" : "Vetëm UDP",
    "TCP only" : "Vetëm TCP",
    "TURN server protocols" : "Protokollet e serverit TURN",
    "Screensharing is not supported by your browser." : "Ndarja e erkaneve nuk është e mbështetur nga shfletuesi juaj ",
    "Screensharing requires the page to be loaded through HTTPS." : "Ndarja e ekranit kërkon faqen të ngarkohet përmes HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Ndarja e ekranit punon vetëm me Firefox, versionin 52 ose më të ri.",
    "Screensharing extension is required to share your screen." : "Zgjerim i ndarja së Ekranit është i nevojshëm për të ndarë ekranin tuaj.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Ju lutem përdorni një browser tjetër si Firefox ose Chrome për të ndarë ekranin tuaj.",
    "An error occurred while starting screensharing." : "Ndodhi një gabim gjatë fillimit të ndarjes së ekranit.",
    "Waiting for {participantName} to join the call …" : "Duke pritur për {participantName} që ti bashkohet telefonatës ...",
    "Waiting for others to join the call …" : "Duke pritur që të tjerët t'i bashkohen thirrjes ...",
    "Copy" : "Kopjo",
    "Copied!" : "U kopjua!",
    "Not supported!" : "Nuk mbështetet!",
    "Press ⌘-C to copy." : "Shtyni ⌘-C që të kopjoni.",
    "Press Ctrl-C to copy." : "Shtyp Ctrl-C për të kopjuar",
    "Share screen" : "Ndaje ekranin",
    "Show your screen" : "Shfaq ekranin tënd",
    "Stop screensharing" : "Ndalo ndarjen e ekranit",
    "Password" : "Fjalëkalim",
    "Cancel" : "Anulo",
    "Leave call" : "Lini një thirrje",
    "Share link" : "Shpërndaj ndërlidhjen",
    "Rename" : "Riemëroj",
    "You" : "Ju",
    "Guest" : "I ftuar",
    "No other people in this call" : "Jo njerëz të tjerë në këtë thirrje",
    "Waiting for camera and microphone permissions" : "Duke pritur për autorizimin e kameras dhe mikrofonit ",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Ju lutemi, ti jepni akses browser-it tuaj për të përdorur kameran dhe mikrofonin në mënyrë që të përdorni këtë app.",
    "Disable video" : "Çaktivizo video",
    "Access to microphone & camera is only possible with HTTPS" : "Aksesi në mikrofon & kamera është i mundur vetëm me HTTPS",
    "Access to microphone & camera was denied" : "Aksesi tek mikrofoni & kamera u mohua",
    "WebRTC is not supported in your browser" : "WebRTC nuk mbështetet nga shfletuesi juaj.",
    "Please use a different browser like Firefox or Chrome" : "Ju lutem zgjidhni një shfletues tjetër si Firefox apo Chrome",
    "Error while accessing microphone & camera" : "gabim ",
    "WebRTC is not supported in your browser :-/" : "WebRTC nuk suportohet nga shfletuesi juaj :-/",
    "{participantName}'s screen" : "Ekrani i {participantName}",
    "Guest's screen" : "Ekrani i të ftuarit",
    "Your screen" : "Ekrani juaj",
    "_%n guest_::_%n guests_" : ["%n të ftuar","%n të ftuar"],
    "_%n other guest_::_%n other guests_" : ["%n përdorues të tjerë","%n të tjerë"],
    ", " : ",",
    "%s invited you to a private conversation" : "%s ju ftoi në një bisedë private",
    "%s invited you to a group conversation: %s" : "%s ju ftoi në një bisedë grupi: %s",
    "TURN server" : "Serveri TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "Serveri TURN përdoret për të përcjellë trafikun nga pjesëmarrësit pas një firewalli.",
    "Video calls" : "Telefonata video",
    "(group)" : "(grup)",
    "New public call" : "Thirrje e re publike",
    "Looking great today! :)" : "Ju dukeni perfekt sot! :)",
    "Time to call your friends" : "Koha për të thirrur shokët tuaj",
    "You can set your name on the top right of this page so other participants can identify you better." : "Ju mund të vendosni emrin tuaj në të djathtën e sipërme të kësaj faqeje që pjesëmarrësit e tjerë tju indentifikojnë më mirë ",
    "This call has ended" : "Kjo thirrje ka përfunduar",
    "Saving failed" : "Ruajtja dështoi",
    "Add person" : "Shto person",
    "and you" : "dhe ju",
    "Please adjust your configuration" : "Ju lutem rregulloni konfigurimin tuaj",
    "{actor} invited you to a private call" : "{actor} ju ftoi në një telefonatë private",
    "{actor} invited you to a group call" : "{actor} ju ftoi për një telefonatë grupi",
    "{actor} invited you to the call {call}" : "{actor} ju ftoi në thirrjen {call}",
    "You were invited to a <strong>video call</strong>" : "Ju jeni ftuar në një <strong> thirrje videoje</strong>",
    "Video call" : "Thirrje me Video",
    "Invalid format, must be stunserver:port." : "Format i pavlefshëm, duhet të jetë stunserver:port.",
    "Invalid port specified." : "Port i specfikuar në mënyrë të gabuar.",
    "Invalid protocols specified." : "Protokolle të pavlefshme të specifikuara",
    "%s invited you to a private call" : "%s ju ftoi në një thirrje private",
    "{user} invited you to a private call" : "{user} ju ftoi në një thirrje private",
    "%s invited you to a group call: %s" : "%s ju ka ftuar në një thirrje grupi: %s",
    "{user} invited you to a group call: {call}" : "{user} ju ftoi në një thirrje grupi: {call}",
    "%s invited you to a group call" : "%s ju ftoi t'i bashkoheni një thirrje në grup",
    "{user} invited you to a group call" : "{user} ju ftoi në një thirrje në grup",
    "Fullscreen" : "Ekran i plotë",
    "Mute audio" : "Mute audio",
    "Smile in 3… 2… 1!" : "Buzëqesh në 3...2...1!",
    "Choose person …" : "Zgjidhni personin ...",
    "The STUN server is necessary so participants can connect to calls. The TURN server makes sure connection works even through firewalls." : "Serveri STUN është i nevojshëm që pjesëmarrësit të mund të lidhen me thirrjet. Serveri TURN siguron që lidhja të funksionojë edhe përmes firewalls.",
    "STUN server" : "Server STUN",
    "The STUN server is used to determine the public IP address of participants behind a router." : "Serveri STUN përdoret për të përcaktuar adresë IP publike të pjesëmarrësve prapa një routeri.",
    "%s mentioned you in a group conversation: %s" : "%s ju përmendi në një bisedë grupi: %s",
    "A guest mentioned you in a group conversation: %s" : "Një i ftuar ju përmendi në një bisedë grupi: %s"
},
"nplurals=2; plural=(n != 1);");
